@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -22,20 +22,20 @@
 
 #include <gtk/gtk.h>
 
-void on_button6_clicked(GtkButton *button, gpointer user_data);
-void on_button7_clicked(GtkButton *button, gpointer user_data);
-void on_button8_clicked(GtkButton *button, gpointer user_data);
-void on_button9_clicked(GtkButton *button, gpointer user_data);
-void on_button23_clicked(GtkButton *button, gpointer user_data);
-void on_button24_clicked(GtkButton *button, gpointer user_data);
-void on_button25_clicked(GtkButton *button, gpointer user_data);
-void on_button26_clicked(GtkButton *button, gpointer user_data);
-void on_okbutton1_clicked(GtkButton *button, gpointer user_data);
-void on_cancelbutton1_clicked(GtkButton *button, gpointer user_data);
+typedef struct { 
+	void *x;
+	void *y; 
+	void *z;
+} xyz_t;
+
+void on_addbutton_clicked(GtkButton *button, gpointer user_data);
+void on_editbutton_clicked(GtkButton *button, gpointer user_data);
+void on_deletebutton_clicked(GtkButton *button, gpointer user_data);
+void on_okbutton_clicked(GtkButton *button, gpointer user_data);
+void on_cancelbutton_clicked(GtkButton *button, gpointer user_data);
+void on_extension_install_check(gpointer user_data);
 
 gboolean on_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 gboolean on_key_release_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 
-void on_window2_delete_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
-
 #endif /* _CALLBACKS_H_ */
