@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2008 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -42,7 +42,7 @@ add_pixmap_directory                   (const gchar     *directory)
 }
 
 /* This is an internally used function to find pixmap files. */
-static gchar*
+gchar*
 find_pixmap_file                       (const gchar     *filename)
 {
   GList *elem;
