@@ -13,24 +13,48 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
 #ifndef _TRAYICON_H_
 #define _TRAYICON_H_
 
+#include "tray_widget.h"
+
+#define MAX_LAYOUTS 4
+
+#ifdef HAVE_APP_INDICATOR
+#include <libappindicator/app-indicator.h>
+#endif
+
 struct _tray_icon
 {
-	struct _tray_widget *widget;
-
+#ifdef HAVE_APP_INDICATOR
+	// App Indicator part
+	AppIndicator *app_indicator;
+#endif
+	
+	// Tray part
+	GtkTrayIcon *tray_icon;
 	GtkTooltips *tooltip;
 	GtkWidget *image;
-	GtkWidget *popup_menu;
 	GtkWidget *evbox;
-	GtkWidget *clock;
+	
+	// Status Icon part
+	GtkStatusIcon *status_icon;
+
+	// All
+	gchar  *images[MAX_LAYOUTS];
+	GtkMenu *menu;
+	GtkWidget *status;
+	
+	gint height;
 };
 
-void create_tray_icon(struct _tray_icon *tray, gboolean runned);
+void create_tray_icon(void);
+void xneur_start_stop(void);
+void xneur_auto_manual(void);
+void xneur_exit(void);
 
 #endif /* _TRAYICON_H_ */
