@@ -13,63 +13,54 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2010 XNeur Team
  *
  */
  
-#include <X11/XKBlib.h>
 
 #include "xkb.h"
+#include <string.h>
 
-int get_active_keyboard_group(void)
+int get_active_kbd_group(Display *dpy)
 {
-	Display *dpy = XOpenDisplay(NULL);
-
+	if (dpy == NULL)
+		return -1;
 	XkbStateRec xkbState;
 	XkbGetState(dpy, XkbUseCoreKbd, &xkbState);
-	XCloseDisplay(dpy);
 
 	return xkbState.group;
 }
 
-int set_next_keyboard_group(void)
+int get_kbd_group_count(Display *dpy) 
 {
-	Display *dpy = XOpenDisplay(NULL);
+	if (dpy == NULL)
+		return -1;
 
-	int active_layout_group = get_active_keyboard_group();
+    XkbDescRec desc[1];
+    int gc;
+    memset(desc, 0, sizeof(desc));
+    desc->device_spec = XkbUseCoreKbd;
+    XkbGetControls(dpy, XkbGroupsWrapMask, desc);
+    XkbGetNames(dpy, XkbGroupNamesMask, desc);
+	gc = desc->ctrls->num_groups;
+    XkbFreeControls(desc, XkbGroupsWrapMask, True);
+    XkbFreeNames(desc, XkbGroupNamesMask, True);
+
+    return gc;
+}
+
+int set_next_kbd_group(Display *dpy)
+{
+	if (dpy == NULL)
+		return -1;
+
+	int active_layout_group = get_active_kbd_group(dpy);
 	
-	XkbDescRec *kbd_desc_ptr = XkbAllocKeyboard();
-	if (kbd_desc_ptr == NULL)
-		return 0;
-
-	XkbGetControls(dpy, XkbAllControlsMask, kbd_desc_ptr);
-	XkbGetNames(dpy, XkbSymbolsNameMask, kbd_desc_ptr);
-	XkbGetNames(dpy, XkbGroupNamesMask, kbd_desc_ptr);	
-	if (kbd_desc_ptr->names == NULL)
-		return 0;
-
-	const Atom *group_source = kbd_desc_ptr->names->groups;
-	int groups_count = 0;
-
-	if (kbd_desc_ptr->ctrls != NULL)
-		groups_count = kbd_desc_ptr->ctrls->num_groups;
-	else
-	{
-		for (; groups_count < XkbNumKbdGroups; groups_count++)
-		{
-			if (group_source[groups_count] == None)
-				break;
-		}
-	}
-
-	if (groups_count == 0)
-		return 0;
-
 	int new_layout_group = active_layout_group + 1;
-	if (new_layout_group == groups_count)
+	if (new_layout_group == get_kbd_group_count(dpy))
 		new_layout_group = 0;
 
 	XkbLockGroup(dpy, XkbUseCoreKbd, new_layout_group);
-	XCloseDisplay(dpy);
+
 	return 1;
 }
