@@ -13,14 +13,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
-#ifndef _XKB_H_
-#define _XKB_H_
+#ifndef _XKBGXNEUR_H_
+#define _XKBGGXNEUR_H_
 
-int get_active_keyboard_group(void);
-int set_next_keyboard_group(void);
+#include <X11/XKBlib.h>
+
+int get_active_kbd_group(Display *dpy);
+int get_kbd_group_count(Display *dpy);
+int set_next_kbd_group(Display *dpy);
 
 #endif /* _XKB_H_ */
